RuntimeBuilder

Struct RuntimeBuilder 

pub struct RuntimeBuilder { /* private fields */ }
Builder for configuring and creating an async runtime.

Provides a convenient way to configure the runtime’s I/O driver before building it.

Examples

use vibeio::RuntimeBuilder;

let runtime = RuntimeBuilder::new()
    .build();

Implementations

Source

impl RuntimeBuilder

pub fn new() -> Self

Creates a new runtime builder with default configuration.

By default, the builder will select the best available driver for the platform.

pub fn driver(self, driver_kind: DriverKind) -> Self

Sets the I/O driver for the runtime.

pub fn enable_timer(self, enable: bool) -> Self

Enables or disables the timer for the runtime.

By default, the timer is disabled.

pub fn enable_fs_offload(self, enable: bool) -> Self

Enables or disables the offload of file I/O to blocking threads for the runtime.

By default, the fs offload is disabled.

pub fn blocking_pool(self, blocking_pool: Box<dyn BlockingThreadPool>) -> Self

Sets the blocking thread pool for the runtime.

pub fn default_blocking_pool(self, max_threads: usize) -> Self

Sets the default blocking thread pool for the runtime with specified maximum number of threads.

pub fn build(self) -> Result<Runtime, Error>

Builds the async runtime with the configured settings.

If no driver was explicitly set, selects the best available driver for the platform.